/*
   Copyright (C) 2009 José Millán Soto <fid@gpul.org>
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "contactnotifierpreferences.h"
#include "ui_contactnotifierpreferences.h"

#include <kgenericfactory.h>
#include <QVBoxLayout>
#include <QWidget>

K_PLUGIN_FACTORY(ContactNotifierPreferencesFactory, registerPlugin<ContactNotifierPreferences>();)
K_EXPORT_PLUGIN(ContactNotifierPreferencesFactory( "kcm_kopete_contactnotifier" ))

ContactNotifierPreferences::ContactNotifierPreferences(QWidget *parent,
    const QVariantList &args)
      : KCModule(ContactNotifierPreferencesFactory::componentData(), parent, args)
{
    QVBoxLayout* l = new QVBoxLayout( this );
    QWidget *w = new QWidget;
    l->addWidget(w);
    m_ui = new Ui::ContactNotifierPreferencesWidget();
    m_ui->setupUi(w);
    connect( m_ui->m_sendIfAwayCheckBox, SIGNAL( stateChanged(int) ),
             this, SLOT ( sendAwayStateChanged(int) ) );
    load();
}

ContactNotifierPreferences::~ContactNotifierPreferences() {
    delete m_ui;
}

void ContactNotifierPreferences::sendAwayStateChanged(int state) {
    m_sendIfAway = (state == Qt::Checked);
    emit changed(true);
}

void ContactNotifierPreferences::updateUi() {
    m_ui->m_sendIfAwayCheckBox->setChecked(m_sendIfAway);
}

void ContactNotifierPreferences::defaults() {
    m_sendIfAway = false;
    updateUi();
    emit changed(true);
}

void ContactNotifierPreferences::load() {
    KSharedConfigPtr cPtr = KSharedConfig::openConfig();
    KConfigGroup cGroup(cPtr, "ContactNotifier");
    m_sendIfAway = cGroup.readEntry<bool>("SendIfAway", false);
    updateUi();
}

void ContactNotifierPreferences::save() {
    KSharedConfigPtr cPtr = KSharedConfig::openConfig();
    KConfigGroup cGroup(cPtr, "ContactNotifier");
    cGroup.writeEntry<bool>("SendIfAway", m_sendIfAway);
    cGroup.sync();
}
